{% extends "admin/change_list.html" %}

{% load i18n admin_list %}

{% block object-tools-items %}
	<li>
		<a href="import_bibtex/" class="addlink focus">{% trans 'Import BibTex' %}</a>
	</li>
	<li>
		<a href="add/{% if is_popup %}?_popup=1{% endif %}" class="addlink focus">
			{% blocktrans with cl.opts.verbose_name as name %}Add {{ name }}{% endblocktrans %}
		</a>
	</li>
{% endblock %}
