{% extends "publications_bootstrap/base.html" %}
{% load publication_extras %}

{% block app_head %}
    <meta name="citation_date" content="{{ publication.year }}"/>
    <meta name="citation_title" content="{{ publication.title }}"/>
{% for author in publication.authors_list %}
    <meta name="citation_author" content="{{ author }}"/>
{% endfor %}
{% if publication.journal %}
    <meta name="citation_journal_title" content="{{ publication.journal }}"/>
{% endif %}
{% if publication.volume %}
    <meta name="citation_volume" content="{{ publication.volume }}"/>
{% endif %}
{% if publication.issue %}
    <meta name="citation_issue" content="{{ publication.issue }}"/>
{% endif %}
{% if publication.pdf %}
    <meta name="citation_pdf_url" content="{{ publication.pdf.url }}"/>
{% endif %}
{% if publication.doi %}
    <meta name="citation_doi" content="{{ publication.doi }}"/>
{% endif %}
{% if publication.publisher %}
    <meta name="citation_publisher" content="{{ publication.publisher }}"/>
{% endif %}
{% if publication.institution %}
    <meta name="citation_technical_report_institution" content="{{ publication.institution }}"/>{% endif %}
{% if publication.first_page %}
    <meta name="citation_firstpage" content="{{ publication.first_page }}"/>
{% endif %}
{% if publication.last_page %}
    <meta name="citation_lastpage" content="{{ publication.last_page }}"/>
{% endif %}
{% endblock %}

{% block app_content %}
    {% include 'publications_bootstrap/components/section.html' with publications=publication|as_list %}
    <h1>Reference</h1>
    <hr/>
    <pre lang="bibtex">{% include "publications_bootstrap/export/publication.bib" %}</pre>
{% endblock %}
