from django.apps import AppConfig


class PublicationsBootstrapConfig(AppConfig):
    name = 'publications_bootstrap'
    verbose_name = "Bootstrap-powered scientific publications for Django"

    # TODO: check if dependencies are met
