<?xml version="1.1" encoding="utf-8"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="en">
<head>
    <meta charset="utf-8">
    <meta http-equiv="x-ua-compatible" content="ie=edge">
    <title>django-publications</title>
    <meta name="description" content="A Django app for managing scientific publications">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">

    {% block head %}
    {% endblock head %}

    {% block css %}
        <style type="text/css">
            body {
                font-family: "Hiragino Sans GB", "Helvetica Neue", "Lucida Grande", Helvetica, Arial, sans-serif;
                font-size: 10pt;
                line-height: 14pt;
                padding: 20px;
            }
        </style>
    {% endblock %}
</head>

<body>

{% if messages %}
    {% for message in messages %}
        <div class="alert {% if message.tags %}alert-{{ message.tags }}{% endif %}">{{ message }}</div>
    {% endfor %}
{% endif %}

<div class="container">
    {% block content %}
        <p>Use this document as a way to quick start any new project.</p>
    {% endblock content %}
</div> <!-- /container -->

{% block js %}
    <!-- Le javascript
    ================================================== -->
    <!-- Placed at the end of the document so the pages load faster -->

    <!-- HTML5 shim, for IE6-8 support of HTML5 elements -->
    <!--[if lt IE 9]>
      <script src="https://cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.3/html5shiv.min.js"></script>
    <![endif]-->

{% endblock js %}
</body>
</html>
