{% load static %}
<a href="{{ urls.up }}{{query_string}}">
    <img src="{% static 'ordered_model/arrow-up.gif' %}"></a>
<a href="{{ urls.down }}{{query_string}}">
    <img src="{% static 'ordered_model/arrow-down.gif' %}"></a>
