<section class="download_all">
    <div class="input-group">
        <span class="input-group-addon" id="basic-addon">Export all as</span>
        <div class="input-group-btn">
            <button type="button" class="btn btn-secondary dropdown-toggle" data-toggle="dropdown"
                    aria-haspopup="true" aria-expanded="false">
                Citation format
            </button>
            <div class="dropdown-menu">
                <a class="dropdown-item" href="?plain">Plain text</a>
                <a class="dropdown-item" href="?ris">RIS</a>
                <a class="dropdown-item" href="?bibtex">BibTex</a>
            </div>
        </div>
    </div>
</section>
